# sopel-deepl

DeepL translation plugin for Sopel IRC bots.

## Usage

```
.deepl [text to translate into English]
```

## Limitations

This plugin does not *yet* support specifying the source/destination
languages, which is a nifty feature of Sopel 7's own built-in `translate`
plugin. Support for doing so is planned for a future release.
